@@ -24,6 +24,7 @@
 #include <config.h>
 #endif
 
+#include <string.h>
 #include "yelp-history.h"
 
 static void    yelp_history_init              (YelpHistory      *history);
@@ -194,6 +195,11 @@ yelp_history_goto (YelpHistory *history, const gchar *location)
 	g_return_if_fail (YELP_IS_HISTORY (history));
 
 	priv = history->priv;
+
+	if (priv->current && priv->current->data && 
+	    !strcmp ((gchar *)priv->current->data, location)) {
+		return;
+	}
 	
 	if (yelp_history_exist_forward (history)) {
 		forward_list = priv->current->next;
